@@ -760,6 +760,11 @@ END
 print "\nSMTP SERVER = $smtp_server and\nVERIFIED_EMAIL = $verified_email and\nSMTPPASS=$smtppass and\nID=$hash->{AccessKey}->{AccessKeyId}\n";
    print "\n   ACCESS GNU SOCIAL UI AT:\n\n",
          " https://$public_ip/index.php\n";
+   my $authinfo=<<END;
+AuthInfo:\\x24smtp_server \\x22U:root\\x22 \\x22I:\\x24hash->{AccessKey}->{AccessKeyId}\\x22 \\x22P:\\x24smtppass\\x22 \\x22M:PLAIN\\x22
+END
+   ($stdout,$stderr)=$handle->cmd(
+      "echo -e \"$authinfo\" > /etc/mail/authinfo");
    my $thanks=<<'END';
 
      ______                  _    ,
@@ -1137,6 +1142,7 @@ END
 
 our $gnusocial_validate_email=sub {
 
+   package gnusocial_validate_email;
    my $email="]I[{'gnusocial_enter_email_address',1}";
    my $confirm="]I[{'gnusocial_enter_email_address',2}";
    unless ($email eq $confirm) {
@@ -1156,7 +1162,7 @@ our $gnusocial_validate_email=sub {
       return '<';
    }
    my $c="aws ses verify-email-identity --email-address $email";
-   my ($hash,$output,$error)=run_aws_cmd($c);
+   my ($hash,$output,$error)=&Net::FullAuto::Cloud::fa_amazon::run_aws_cmd($c);
    my $inform_banner=<<'END';
 
     ___                     _            _   _
@@ -1180,7 +1186,7 @@ END
    my $email_message={
 
       Name => 'email_message',
-      Result => $check_elastic_ip,
+      Result => $Net::FullAuto::ISets::Amazon::GNUSocial_is::check_elastic_ip,
       Banner => $inform_banner,
 
    };
@@ -1200,9 +1206,12 @@ our $gnusocial_enter_email_address=sub {
 END
    $gnusocial_email_banner.=<<END;
 
-   Type or Copy & Paste the main contact email for GNU Social here:
+   Input box with === border is highlighted (active) input box.
+   Use [TAB] key to switch focus between input boxes.
+   Use [DEL] key to clear entire entry in highlighted input box.
+   Use [Backspace] to backspace in highlighted input box.
 
-   (Use [TAB] key to switch between input boxes)
+   Type or Copy & Paste the main contact email for GNU Social here:
 
 
    Email Address
@@ -1272,7 +1281,7 @@ END
 
             Text => "]C[",
             Convey => \@identities,
-            Result => $check_elastic_ip,
+            Result => $Net::FullAuto::ISets::Amazon::GNUSocial_is::check_elastic_ip,
 
          },
          Scroll => 2,
